@@ -17,7 +17,7 @@ from ae.base import UNSET
 from ae.deep import deep_object, deep_replace                                               # type: ignore
 
 
-__version__ = '0.2.5'
+__version__ = '0.2.6'
 
 
 class DynamicChildrenBehavior:
@@ -73,8 +73,6 @@ class DynamicChildrenBehavior:
             children_container = init_kwargs.get('container', getattr(self, 'container', self))
         if not hasattr(super(), 'container'):
             self.container = children_container
-        if 'orientation' not in init_kwargs and getattr(children_container, 'orientation', None) == 'horizontal':
-            children_container.orientation = 'vertical'     # default for BoxLayout/Popup-container
 
         for child in self._map_children:
             children_container.remove_widget(child)
